@@ -434,40 +434,36 @@ impl AssignFolder {
                 right: def_value,
                 ..
             }) => {
-                assert!(
-                    decl.init.is_some(),
-                    "destructuring pattern binding requires initializer"
-                );
+                let init = if let Some(init) = decl.init {
+                    let tmp_ident = match &*init {
+                        Expr::Ident(ref i) if i.span.ctxt() != SyntaxContext::empty() => i.clone(),
 
-                let init = decl.init;
-                let tmp_ident: Ident = (|| {
-                    if let Some(ref e) = init {
-                        match &**e {
-                            Expr::Ident(ref i) if i.span.ctxt() != SyntaxContext::empty() => {
-                                return i.clone();
-                            }
-                            _ => {}
+                        _ => {
+                            let tmp_ident = private_ident!(span, "tmp");
+                            decls.push(VarDeclarator {
+                                span: DUMMY_SP,
+                                name: tmp_ident.clone().into(),
+                                init: Some(init),
+                                definite: false,
+                            });
+
+                            tmp_ident
                         }
-                    }
+                    };
 
-                    let tmp_ident = private_ident!(span, "tmp");
-                    decls.push(VarDeclarator {
-                        span: DUMMY_SP,
-                        name: tmp_ident.clone().into(),
-                        init,
-                        definite: false,
-                    });
-
-                    tmp_ident
-                })();
+                    // tmp === void 0 ? def_value : tmp
+                    Some(Box::new(make_cond_expr(tmp_ident, def_value)))
+                } else {
+                    Some(def_value)
+                };
 
                 let var_decl = VarDeclarator {
                     span,
                     name: *left,
-                    // tmp === void 0 ? def_value : tmp
-                    init: Some(Box::new(make_cond_expr(tmp_ident, def_value))),
+                    init,
                     definite: false,
                 };
+
                 let mut var_decls = vec![var_decl];
                 var_decls.visit_mut_with(self);
                 decls.extend(var_decls);
