@@ -1,5 +1,7 @@
+use std::{fs::read_to_string, path::PathBuf};
 use swc_common::{chain, Mark};
 use swc_ecma_parser::Syntax;
+use swc_ecma_transforms_base::resolver::resolver;
 use swc_ecma_transforms_compat::{
     es2015,
     es2015::{block_scoping, for_of::for_of},
@@ -1008,3 +1010,13 @@ for (let b = 0; b < a; b++) {
 expect(expected).toEqual([0,1,2,3,4]);
 "
 );
+
+#[testing::fixture("tests/block-scoping/**/exec.js")]
+fn exec(input: PathBuf) {
+    let input = read_to_string(&input).unwrap();
+    compare_stdout(
+        Default::default(),
+        |_| chain!(resolver(), block_scoping()),
+        &input,
+    );
+}
